MetisStats

Struct MetisStats 

pub struct MetisStats {
    pub n_levels: u32,
    pub n_components: u32,
    pub n_separator_vertices: u32,
    pub n_fm_passes: u32,
    pub n_two_hop_fallbacks: u32,
    pub n_amd_leaf_calls: u32,
}
Crate-specific diagnostic counters for METIS nested dissection.

Populated per call to metis_order_full. Callers that only need the permutation should use metis_order; callers that need the shared OrderingStats (wall time) should use metis_order_full.

Fields

n_levels: u32

Number of coarsening levels built.

n_components: u32

Number of top-level connected components encountered.

n_separator_vertices: u32

Number of vertices assigned to a separator at any level.

n_fm_passes: u32

Number of FM passes executed across all levels.

n_two_hop_fallbacks: u32

Number of times SHEM fell through to the 2-hop matching path.

n_amd_leaf_calls: u32

Number of subgraphs handed off to the AMD leaf solver (when nd_to_amd_switch triggers).